@@ -19,3 +19,8 @@
 
 pub const COMPONENT_PHP_ID: i32 = 8001;
 pub const COMPONENT_PHP_CURL_ID: i32 = 8002;
+pub const COMPONENT_PHP_PDO_ID: i32 = 8003;
+pub const COMPONENT_PHP_MYSQLI_ID: i32 = 8004;
+pub const COMPONENT_PHP_PREDIS_ID: i32 = 8006;
+pub const COMPONENT_PHP_MEMCACHED_ID: i32 = 20;
+pub const COMPONENT_PHP_REDIS_ID: i32 = 7;
